xsdata.codegen package
======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   xsdata.codegen.handlers

Submodules
----------

.. toctree::
   :maxdepth: 4

   xsdata.codegen.analyzer
   xsdata.codegen.builder
   xsdata.codegen.container
   xsdata.codegen.mixins
   xsdata.codegen.models
   xsdata.codegen.parser
   xsdata.codegen.resolver
   xsdata.codegen.sanitizer
   xsdata.codegen.transformer
   xsdata.codegen.utils
   xsdata.codegen.validator
   xsdata.codegen.writer

Module contents
---------------

.. automodule:: xsdata.codegen
   :members:
   :undoc-members:
   :show-inheritance:
